Class: SvelteOnRails::SsrServerHelpers
- Inherits:
-
Object
- Object
- SvelteOnRails::SsrServerHelpers
- Defined in:
- lib/svelte_on_rails/ssr_server.rb
Instance Attribute Summary collapse
-
#socket_namespace ⇒ Object
readonly
theese helpers are used from the :check rake task For that reason they are within a separate class.
-
#socket_path(ppid: Process.ppid) ⇒ Object
readonly
theese helpers are used from the :check rake task For that reason they are within a separate class.
Instance Method Summary collapse
-
#initialize ⇒ SsrServerHelpers
constructor
A new instance of SsrServerHelpers.
- #ssr_server_ppid_file ⇒ Object
Constructor Details
#initialize ⇒ SsrServerHelpers
Returns a new instance of SsrServerHelpers.
390 391 392 393 394 395 396 397 398 |
# File 'lib/svelte_on_rails/ssr_server.rb', line 390 def initialize @socket_namespace = [ "svelte-ssr", Rails.application.class.module_parent_name[0..30], Rails.env, ].join("-") end |
Instance Attribute Details
#socket_namespace ⇒ Object (readonly)
theese helpers are used from the :check rake task For that reason they are within a separate class
387 388 389 |
# File 'lib/svelte_on_rails/ssr_server.rb', line 387 def socket_namespace @socket_namespace end |
#socket_path(ppid: Process.ppid) ⇒ Object (readonly)
theese helpers are used from the :check rake task For that reason they are within a separate class
387 388 389 |
# File 'lib/svelte_on_rails/ssr_server.rb', line 387 def socket_path @socket_path end |
Instance Method Details
#ssr_server_ppid_file ⇒ Object
400 401 402 |
# File 'lib/svelte_on_rails/ssr_server.rb', line 400 def ssr_server_ppid_file Rails.root.join("tmp", "pids", 'svelte_on_rails.ppid') end |